/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ;
typedef struct tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA;
typedef struct tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA;
typedef struct tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tySequence__vvBerF0axaNtu9aMA2gnsrA tySequence__vvBerF0axaNtu9aMA2gnsrA;
typedef struct tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ;
typedef struct tySequence__ZQPym9bf1jM5qaSn7LUXMKA tySequence__ZQPym9bf1jM5qaSn7LUXMKA;
typedef struct tySequence__9c3OY0aBmSBgwdsnBAPf4Ag tySequence__9c3OY0aBmSBgwdsnBAPf4Ag;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ;
typedef struct tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__Jhh6ks9carRtwV9aOuM8yMNw tySequence__Jhh6ks9carRtwV9aOuM8yMNw;
typedef struct tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw tySequence__E8pi9b5QNahsURYzXMjh3qw;
typedef struct tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg;
typedef struct tySequence__XDpbjnuseLNZDGLBQ2Qzow tySequence__XDpbjnuseLNZDGLBQ2Qzow;
typedef struct tyObject_Table__cBohObSCAwRxvYFXQHv2wA tyObject_Table__cBohObSCAwRxvYFXQHv2wA;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A tySequence__QqvaCqCpEE1QmQZbcZLi5A;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyTuple__hv7XYxzNv29cYlH39cwb529ag tyTuple__hv7XYxzNv29cYlH39cwb529ag;
typedef struct tyObject_Env_importerdotnim_transformImportAs___AMAna5nUcyswBmZhxx39baQ tyObject_Env_importerdotnim_transformImportAs___AMAna5nUcyswBmZhxx39baQ;
typedef struct tyTuple__HLgvPk0GVvUxspcAPY16vw tyTuple__HLgvPk0GVvUxspcAPY16vw;
typedef struct tySequence__s6XOb8vGaBHi7Py1r5uplQ tySequence__s6XOb8vGaBHi7Py1r5uplQ;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tySequence__RNhZxf20g9beyq5VBOGxhDg tySequence__RNhZxf20g9beyq5VBOGxhDg;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ tySequence__lFbCtu5P2Kf7YDYtGjkxAQ;
typedef struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA;
typedef struct tySequence__ijtae5OneaLys0hN9alAicA tySequence__ijtae5OneaLys0hN9alAicA;
typedef struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w;
typedef struct tySequence__SerjNoUujW2dUouVBrJiCw tySequence__SerjNoUujW2dUouVBrJiCw;
typedef struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyObject_Table__r0v8BdcBPKhl73K8p2VMUA;
typedef struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g tySequence__K9agbtcb0qPZuSJFXB9cTe6g;
typedef struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg;
typedef struct tySequence__m88qdML9cQOuqGAQn6XWL1A tySequence__m88qdML9cQOuqGAQn6XWL1A;
typedef struct tyObject_Table__1hIWbTQWYT4BmhdESze57A tyObject_Table__1hIWbTQWYT4BmhdESze57A;
typedef struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ tySequence__naEbXEp9b9aiW1zXJorqf9cXQ;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tyObject_Table__imojfg883tkWsWJwyshGqQ tyObject_Table__imojfg883tkWsWJwyshGqQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg tyObject_Table__BCPh85PHtwxox9bv7NLFrlg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA;
typedef struct tySequence__KgiZ29chkJAD01p9aLRB32qw tySequence__KgiZ29chkJAD01p9aLRB32qw;
typedef struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A tyObject_Table__LM44poVdVEn4Mo4N4L8c3A;
typedef struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw tySequence__rkYRZrbHVYL3nhXlQW3K9bw;
typedef struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ tySequence__IRFEb1e9bxgbJLuB5xrdZsQ;
typedef struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ;
typedef struct tySequence__YmPd0eWfcTfrVYrthlXPYA tySequence__YmPd0eWfcTfrVYrthlXPYA;
typedef struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q;
typedef struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg tySequence__Hz5SYwQU29b9aFLt09blvVQPg;
typedef struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg tyObject_Table__R7JnJQEipxxOlJWXQz7jWg;
typedef struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ tySequence__3G9aA9cLXaPxuRxMKm3anacQ;
typedef struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q tySequence__bPFv6ypvvCX2A9a9al8utL2Q;
typedef struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg;
typedef struct tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg;
typedef struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg;
typedef struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ;
typedef struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g tySequence__qeAsXh2i1GAL5Nl0g3OP8g;
typedef struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A;
typedef struct tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g;
typedef struct tyObject_RodIter__L6nv9cakjPARHk068AFo6ww tyObject_RodIter__L6nv9cakjPARHk068AFo6ww;
typedef struct tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA;
typedef struct tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyTuple__VbApVidEWCFLq9a29bPtaS7A tyTuple__VbApVidEWCFLq9a29bPtaS7A;
typedef struct tySequence__k7EQb9bN3Uhl608xoPGMRJA tySequence__k7EQb9bN3Uhl608xoPGMRJA;
typedef struct tyTuple__toqrUPSdp8zSxOdlxMJj9cA tyTuple__toqrUPSdp8zSxOdlxMJj9cA;
typedef struct tyTuple__EbsafWGli8bW2GRJQ9apsjA tyTuple__EbsafWGli8bW2GRJQ9apsjA;
typedef struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ;
typedef struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg tyTuple__UluY8x0Nj6cp9b0o88wJ0lg;
typedef struct tySequence__dlD6tEGzYLLpKVq3XwuFlA tySequence__dlD6tEGzYLLpKVq3XwuFlA;
typedef struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ;
typedef struct tyTuple__rZZA0skon1OsHdiEvT8RZQ tyTuple__rZZA0skon1OsHdiEvT8RZQ;
typedef struct tySequence__6OFCSvqRaxyEgUqWtnZSlw tySequence__6OFCSvqRaxyEgUqWtnZSlw;
typedef struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q;
typedef struct tySequence__UnGSk9aaLosDroi2QDrlOfQ tySequence__UnGSk9aaLosDroi2QDrlOfQ;
typedef struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA tyTuple__q13Zt16VkCqu6Zg5jWqwHA;
typedef struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA tyTuple__aWN9bNzF9bubXNJV9ciomgpfA;
typedef struct tySequence__m4PVWjcAAjfxlwJxLkKn8A tySequence__m4PVWjcAAjfxlwJxLkKn8A;
typedef struct tyTuple__RWXAsQlFoGYyEQZp1G65sg tyTuple__RWXAsQlFoGYyEQZp1G65sg;
typedef struct tyTuple__RmGJuqOgEaHckHndh0LEsw tyTuple__RmGJuqOgEaHckHndh0LEsw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__J4cxakKjhKxTIJR9bojMmXw tyTuple__J4cxakKjhKxTIJR9bojMmXw;
typedef struct tySequence__i89c5kdtWKzK3OEiI81pkkw tySequence__i89c5kdtWKzK3OEiI81pkkw;
typedef struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A;
typedef struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ;
typedef struct tySequence__GR8qmV1kNRcoQ2g76VFy3A tySequence__GR8qmV1kNRcoQ2g76VFy3A;
typedef struct tyTuple__a7QginWFapakKbWJBJ2vfA tyTuple__a7QginWFapakKbWJBJ2vfA;
typedef struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__kbX6x85REySUrk9auORL0vw tyTuple__kbX6x85REySUrk9auORL0vw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g;
typedef struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q;
typedef struct tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A;
typedef struct tyTuple__nF9cH4hinXgGEUwO4G2bshw tyTuple__nF9cH4hinXgGEUwO4G2bshw;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw {
  RootObj Sup;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__aaEwD7wUZoIxDUprFEbfMQ[38];
struct tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ {
NI counter;
tySequence__ZQPym9bf1jM5qaSn7LUXMKA* data;
};
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__q9caIJqxIEVMlKzDKc7PN3A) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* expectedType);
typedef NU32 tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__Kiet6YwcQwPvcQYHHEqqqQ) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* expectedType);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__PSlVV9bxpH9avY5YrjCD5uqA) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__8k9afYvvfaH1tjWAwlISb0A) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0);
void* ClE_0;
} tyProc__9bnYcX9avusKBraL3FJXBwJw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__uojbiMfaKLMuGW9bbomtTBg) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
typedef NU32 tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__bqRyngJC8bSPcUqqn9bn73w) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nOrig, tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw filter, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags);
typedef N_NIMCALL_PTR(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, tyProc__F6LocU8y66ng5Ra4XoVWJA) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prev);
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0);
void* ClE_0;
} tyProc__Nc9aAsBDTkr61wP9a9cnds8Og;
typedef struct {
N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, void* ClE_0);
void* ClE_0;
} tyProc__z8FaSv6eEIc72FZ9c9cBcaGg;
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__9aa59awckKpa9areOQSBOwSeQ) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* dc, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op, NI col);
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
struct tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ {
tySequence__Bis5AbpONWcIRrPyPJS8Yw* data;
NI counter;
};
struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg {
tySequence__E8pi9b5QNahsURYzXMjh3qw* data;
NI counter;
};
struct tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg {
tySequence__XDpbjnuseLNZDGLBQ2Qzow* data;
NI counter;
};
struct tyObject_Table__cBohObSCAwRxvYFXQHv2wA {
tySequence__QqvaCqCpEE1QmQZbcZLi5A* data;
NI counter;
};
struct tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw {
  tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw Sup;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* enforceVoidContext;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* voidType;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* currentScope;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* moduleScope;
tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA* imports;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* topLevelScope;
tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA* p;
tyArray__aaEwD7wUZoIxDUprFEbfMQ intTypeCache;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* nilTypeCache;
tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw* matchedConcept;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* friendModules;
NI instCounter;
NI* templInstCounter;
NI inGenericContext;
NI inStaticContext;
NI inUnrolledContext;
NI compilesContextId;
NI compilesContextIdGenerator;
NI inGenericInst;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* converters;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* patterns;
tySequence__vvBerF0axaNtu9aMA2gnsrA* optionStack;
tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ symMapping;
tySequence__9c3OY0aBmSBgwdsnBAPf4Ag* libs;
tyProc__q9caIJqxIEVMlKzDKc7PN3A semConstExpr;
tyProc__Kiet6YwcQwPvcQYHHEqqqQ semExpr;
tyProc__PSlVV9bxpH9avY5YrjCD5uqA semTryExpr;
tyProc__q9caIJqxIEVMlKzDKc7PN3A semTryConstExpr;
tyProc__8k9afYvvfaH1tjWAwlISb0A computeRequiresInit;
tyProc__9bnYcX9avusKBraL3FJXBwJw hasUnresolvedArgs;
tyProc__PSlVV9bxpH9avY5YrjCD5uqA semOperand;
tyProc__uojbiMfaKLMuGW9bbomtTBg semConstBoolExpr;
tyProc__bqRyngJC8bSPcUqqn9bn73w semOverloadedCall;
tyProc__F6LocU8y66ng5Ra4XoVWJA semTypeNode;
tyProc__Nc9aAsBDTkr61wP9a9cnds8Og semInferredLambda;
tyProc__z8FaSv6eEIc72FZ9c9cBcaGg semGenerateInstance;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw includedFiles;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw pureEnumFields;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw userPragmas;
tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ* evalContext;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw unknownIdents;
tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ* generics;
NI topStmts;
NI lastGenericIdx;
NI hloLoopDetector;
NI inParallelStmt;
tyProc__9aa59awckKpa9areOQSBOwSeQ instTypeBoundOp;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* selfName;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw signatures;
NimStringDesc* recursiveDep;
NIM_BOOL suggestionsMade;
NIM_BOOL isAmbiguous;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
NI inTypeContext;
NI inConceptDecl;
tySequence__Jhh6ks9carRtwV9aOuM8yMNw* unusedImports;
tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ exportIndirections;
tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg importModuleMap;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastTLineInfo;
tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg sideEffects;
NI inUncheckedAssignSection;
tyObject_Table__cBohObSCAwRxvYFXQHv2wA importModuleLookup;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
struct tyTuple__hv7XYxzNv29cYlH39cwb529ag {
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field0;
NIM_BOOL Field1;
};
struct tyObject_Env_importerdotnim_transformImportAs___AMAna5nUcyswBmZhxx39baQ {
  RootObj Sup;
NI colonstate_;
tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c1;
tyTuple__hv7XYxzNv29cYlH39cwb529ag ret2;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n3;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU16 tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw;
struct tyTuple__HLgvPk0GVvUxspcAPY16vw {
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field0;
tySequence__s6XOb8vGaBHi7Py1r5uplQ* Field1;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA {
tySequence__ijtae5OneaLys0hN9alAicA* data;
NI counter;
};
struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w {
tySequence__SerjNoUujW2dUouVBrJiCw* data;
NI counter;
};
struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA {
tySequence__K9agbtcb0qPZuSJFXB9cTe6g* data;
NI counter;
};
typedef tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyArray__46hjIasL27aUz9c7kgtWooQ[5];
struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg {
tySequence__m88qdML9cQOuqGAQn6XWL1A* data;
NI counter;
};
struct tyObject_Table__1hIWbTQWYT4BmhdESze57A {
tySequence__naEbXEp9b9aiW1zXJorqf9cXQ* data;
NI counter;
};
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_Table__imojfg883tkWsWJwyshGqQ {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA {
tySequence__KgiZ29chkJAD01p9aLRB32qw* data;
NI counter;
};
struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A {
tySequence__rkYRZrbHVYL3nhXlQW3K9bw* data;
NI counter;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg[65];
struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ {
tySequence__YmPd0eWfcTfrVYrthlXPYA* data;
NI counter;
};
struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__I6rzVhdiYtUh7jwWJQoeyw) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__EQOAUyRkp9c3eeiGlHvCThA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q {
tySequence__Hz5SYwQU29b9aFLt09blvVQPg* data;
NI counter;
};
struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg {
tySequence__3G9aA9cLXaPxuRxMKm3anacQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__1CO5eEh25fBKUWGagpikwg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef N_NIMCALL_PTR(void, tyProc__VcUg5jOhttLagdxUmVN8Tg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__XOkru1xuh2bHzmkw1UYzLA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* actual);
struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opNot;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opContains;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLe;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLt;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAnd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opOr;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opIsNil;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opEq;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAdd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opSub;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opMul;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opDiv;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg {
tySequence__RNhZxf20g9beyq5VBOGxhDg* ifaces;
tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* packed_0;
tySequence__lFbCtu5P2Kf7YDYtGjkxAQ* encoders;
tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA typeInstCache;
tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w procInstCache;
tyArray__46hjIasL27aUz9c7kgtWooQ attachedOps;
tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg methodsPerType;
tyObject_Table__1hIWbTQWYT4BmhdESze57A enumToStringProcs;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw emittedTypeInfo;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA startupPackedConfig;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw deps;
tyObject_Table__imojfg883tkWsWJwyshGqQ importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__BCPh85PHtwxox9bv7NLFrlg inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* usageSym;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* owners;
tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA suggestSymbols;
tyObject_Table__LM44poVdVEn4Mo4N4L8c3A suggestErrors;
tySequence__IRFEb1e9bxgbJLuB5xrdZsQ* methods;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* systemModule;
tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg sysTypes;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw compilerprocs;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw exposed;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageTypes;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ canonTypes;
tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw symBodyHashes;
tyProc__I6rzVhdiYtUh7jwWJQoeyw importModuleCallback;
tyProc__EQOAUyRkp9c3eeiGlHvCThA includeFileCallback;
tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q cacheSeqs;
tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g cacheCounters;
tyObject_Table__R7JnJQEipxxOlJWXQz7jWg cacheTables;
tySequence__bPFv6ypvvCX2A9a9al8utL2Q* passes;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinition;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinitionResolveForward;
tyProc__1CO5eEh25fBKUWGagpikwg onUsage;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* globalDestructors;
tyProc__VcUg5jOhttLagdxUmVN8Tg strongSemCheck;
tyProc__XOkru1xuh2bHzmkw1UYzLA compatibleProps;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg operators;
};
typedef NU8 tySet_tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw[37];
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, ClP_0) (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n2, void* ClE_0);
void* ClE_0;
} tyProc__TTCGJ1wsIRuN7Gfv9bQ89bYg;
typedef N_CLOSURE_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_12) (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n2);
typedef N_CLOSURE_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_13) (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n2);
struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg {
NI32 module;
NI32 symId;
NI32 typeId_0;
NIM_BOOL sealed;
};
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
typedef NU8 tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
struct tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field0;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field1;
};
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ;
struct tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m;
tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ mode;
union{
struct {tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw imported;
} _mode_2;
struct {tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw exceptSet;
} _mode_3;
};
};
typedef NU tyArray__VqSA39cBDWnwnJySTumCdjw[8];
struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg {
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* next;
NI key;
tyArray__VqSA39cBDWnwnJySTumCdjw bits;
};
struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* converters;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* patterns;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* pureEnums;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interf;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interfHidden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* uniqueName;
};
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg {
NI module;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ packed_0;
};
struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
struct tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g {
NI h;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
};
struct tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ {
NI lastModule;
NU32 lastLit;
NI32 lastFile;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
};
struct tyObject_RodIter__L6nv9cakjPARHk068AFo6ww {
tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ decoder;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* values;
NI i;
NI module;
};
struct tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A {
NIM_BOOL fromRod;
NI modIndex;
tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g ti;
tyObject_RodIter__L6nv9cakjPARHk068AFo6ww rodIt;
NIM_BOOL importHidden;
};
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
NI Field0;
NI Field1;
};
struct tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA {
tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key;
RootObj* val;
};
struct tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* genericSym;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
NI Field0;
tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tyTuple__toqrUPSdp8zSxOdlxMJj9cA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
struct tyTuple__VbApVidEWCFLq9a29bPtaS7A {
NI Field0;
NI Field1;
tySequence__k7EQb9bN3Uhl608xoPGMRJA* Field2;
};
struct tyTuple__EbsafWGli8bW2GRJQ9apsjA {
NI Field0;
NI Field1;
tySequence__qwqHTkRvwhrRyENtudHQ7g* Field2;
};
struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ {
tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data;
NI counter;
};
struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ {
NI32 thisModule;
NI32 lastFile;
NU32 lastLit;
tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ filenames;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* pendingTypes;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* pendingSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw typeMarker;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw symMarker;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
};
struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__dlD6tEGzYLLpKVq3XwuFlA* Field2;
};
struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q {
NI module;
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg sym;
tySequence__UnGSk9aaLosDroi2QDrlOfQ* concreteTypes;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__rZZA0skon1OsHdiEvT8RZQ {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__6OFCSvqRaxyEgUqWtnZSlw* Field2;
};
struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field2;
};
struct tyTuple__RWXAsQlFoGYyEQZp1G65sg {
NI Field0;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field1;
};
struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__m4PVWjcAAjfxlwJxLkKn8A* Field2;
};
struct tyTuple__RmGJuqOgEaHckHndh0LEsw {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field2;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
};
struct tyTuple__J4cxakKjhKxTIJR9bojMmXw {
NI Field0;
NI32 Field1;
tySequence__i89c5kdtWKzK3OEiI81pkkw* Field2;
};
struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ {
NI Field0;
NI32 Field1;
tySequence__GR8qmV1kNRcoQ2g76VFy3A* Field2;
};
struct tyTuple__a7QginWFapakKbWJBJ2vfA {
tySequence__ed0C0uAUZPhvw3RAc5hfYg* Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__kbX6x85REySUrk9auORL0vw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q {
tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* root;
NI entries;
};
struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, tyProc__kqPx9c4py2HW6KcFMhNvxtg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__9c6qRjwy7Es8UkDTIUwAfFA) (tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__mv4BsRs5VEnhcxzV6pQU5w) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
struct tyTuple__nF9cH4hinXgGEUwO4G2bshw {
tyProc__kqPx9c4py2HW6KcFMhNvxtg Field0;
tyProc__9c6qRjwy7Es8UkDTIUwAfFA Field1;
tyProc__mv4BsRs5VEnhcxzV6pQU5w Field2;
NIM_BOOL Field3;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
NI Field0;
NI32 Field1;
NU32 Field2;
};
struct tySequence__s6XOb8vGaBHi7Py1r5uplQ {
  TGenericSeq Sup;
  tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__Jhh6ks9carRtwV9aOuM8yMNw {
  TGenericSeq Sup;
  tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg data[SEQ_DECL_SIZE];
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  TGenericSeq Sup;
  NI data[SEQ_DECL_SIZE];
};
struct tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA {
  TGenericSeq Sup;
  tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__vvBerF0axaNtu9aMA2gnsrA {
  TGenericSeq Sup;
  tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q* data[SEQ_DECL_SIZE];
};
struct tySequence__ZQPym9bf1jM5qaSn7LUXMKA {
  TGenericSeq Sup;
  tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA data[SEQ_DECL_SIZE];
};
struct tySequence__9c3OY0aBmSBgwdsnBAPf4Ag {
  TGenericSeq Sup;
  tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ {
  TGenericSeq Sup;
  tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w data[SEQ_DECL_SIZE];
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  TGenericSeq Sup;
  tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE];
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw {
  TGenericSeq Sup;
  tyTuple__47w2DboNEPf69aPgubZdd7Q data[SEQ_DECL_SIZE];
};
struct tySequence__k7EQb9bN3Uhl608xoPGMRJA {
  TGenericSeq Sup;
  tyTuple__toqrUPSdp8zSxOdlxMJj9cA data[SEQ_DECL_SIZE];
};
struct tySequence__XDpbjnuseLNZDGLBQ2Qzow {
  TGenericSeq Sup;
  tyTuple__VbApVidEWCFLq9a29bPtaS7A data[SEQ_DECL_SIZE];
};
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A {
  TGenericSeq Sup;
  tyTuple__EbsafWGli8bW2GRJQ9apsjA data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__RNhZxf20g9beyq5VBOGxhDg {
  TGenericSeq Sup;
  tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ {
  TGenericSeq Sup;
  tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ data[SEQ_DECL_SIZE];
};
struct tySequence__dlD6tEGzYLLpKVq3XwuFlA {
  TGenericSeq Sup;
  tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ data[SEQ_DECL_SIZE];
};
struct tySequence__ijtae5OneaLys0hN9alAicA {
  TGenericSeq Sup;
  tyTuple__UluY8x0Nj6cp9b0o88wJ0lg data[SEQ_DECL_SIZE];
};
struct tySequence__6OFCSvqRaxyEgUqWtnZSlw {
  TGenericSeq Sup;
  tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q data[SEQ_DECL_SIZE];
};
struct tySequence__SerjNoUujW2dUouVBrJiCw {
  TGenericSeq Sup;
  tyTuple__rZZA0skon1OsHdiEvT8RZQ data[SEQ_DECL_SIZE];
};
struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g {
  TGenericSeq Sup;
  tyTuple__q13Zt16VkCqu6Zg5jWqwHA data[SEQ_DECL_SIZE];
};
struct tySequence__m4PVWjcAAjfxlwJxLkKn8A {
  TGenericSeq Sup;
  tyTuple__RWXAsQlFoGYyEQZp1G65sg data[SEQ_DECL_SIZE];
};
struct tySequence__m88qdML9cQOuqGAQn6XWL1A {
  TGenericSeq Sup;
  tyTuple__aWN9bNzF9bubXNJV9ciomgpfA data[SEQ_DECL_SIZE];
};
struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ {
  TGenericSeq Sup;
  tyTuple__RmGJuqOgEaHckHndh0LEsw data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__i89c5kdtWKzK3OEiI81pkkw {
  TGenericSeq Sup;
  tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A data[SEQ_DECL_SIZE];
};
struct tySequence__KgiZ29chkJAD01p9aLRB32qw {
  TGenericSeq Sup;
  tyTuple__J4cxakKjhKxTIJR9bojMmXw data[SEQ_DECL_SIZE];
};
struct tySequence__GR8qmV1kNRcoQ2g76VFy3A {
  TGenericSeq Sup;
  tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* data[SEQ_DECL_SIZE];
};
struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw {
  TGenericSeq Sup;
  tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ data[SEQ_DECL_SIZE];
};
struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ {
  TGenericSeq Sup;
  tyTuple__a7QginWFapakKbWJBJ2vfA data[SEQ_DECL_SIZE];
};
struct tySequence__YmPd0eWfcTfrVYrthlXPYA {
  TGenericSeq Sup;
  tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg {
  TGenericSeq Sup;
  tyTuple__kbX6x85REySUrk9auORL0vw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ {
  TGenericSeq Sup;
  tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g data[SEQ_DECL_SIZE];
};
struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q {
  TGenericSeq Sup;
  tyTuple__nF9cH4hinXgGEUwO4G2bshw data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g {
  TGenericSeq Sup;
  tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  TGenericSeq Sup;
  tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
struct tySequence__UnGSk9aaLosDroi2QDrlOfQ {
  TGenericSeq Sup;
  tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, someSymFromImportTable__lookups_561)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, NIM_BOOL* ambiguous);
N_LIB_PRIVATE N_NIMCALL(void, strTableAdd__astalgo_3325)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* t, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3320)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, copyNode__ast_4324)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src);
N_LIB_PRIVATE N_NIMCALL(void, newSons__semtypinst_416)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, NI length);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5319)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5281)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5326)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5324)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5275)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(void, impMod__importer_4966)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* importStmtResult);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, myImportModule__importer_4755)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* importStmtResult);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, transformImportAs__importer_4637)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyTuple__hv7XYxzNv29cYlH39cwb529ag* Result);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tyRef__mzsJbF13j9a1gF8FsVcBslA)(void* p, NI op);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, considerQuotedIdent__lookups_29)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* origin);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_4798)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son);
N_LIB_PRIVATE N_CLOSURE(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, processPragma__importer_4644)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n2, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, splitPragmas__importer_1365)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyTuple__HLgvPk0GVvUxspcAPY16vw* Result);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw, whichKeyword__idents_223)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* id);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
static N_NIMCALL(void, Marker_tySequence__s6XOb8vGaBHi7Py1r5uplQ)(void* p, NI op);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(void, genericSeqAssign)(void* dest, void* src, TNimType* mt);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___importer_4668)(tySet_tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(NI32, checkModuleName__modulepaths_21)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL doLocalError);
N_LIB_PRIVATE N_NIMCALL(void, addImportFileDep__semdata_641)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, NI32 f);
static N_INLINE(NI, find__importer_4766)(tySequence__48JTohSgTy339bRxHzUD8KA* a, NI32 item);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__msgs_548)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q*, pushOptionEntry__semdata_474)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, importModuleAs__importer_2174)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* realModule, NIM_BOOL importHidden);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, createModuleAlias__ast_4069)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* newIdent, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___importer_2265)(tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg* t, NI key, NI val);
N_LIB_PRIVATE N_NIMCALL(void, addUnique__importer_4621)(tySequence__qwqHTkRvwhrRyENtudHQ7g** x, NI y);
N_LIB_PRIVATE N_NIMCALL(tySequence__qwqHTkRvwhrRyENtudHQ7g**, mgetOrPut__importer_3448)(tyObject_Table__cBohObSCAwRxvYFXQHv2wA* t, NI key, tySequence__qwqHTkRvwhrRyENtudHQ7g* val);
N_LIB_PRIVATE N_NIMCALL(void, popOptionEntry__semdata_489)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
static N_INLINE(void, suggestSym__sigmatch_5404)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** usageSym, NIM_BOOL isDecl);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newSymNode__ast_3707)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
static N_INLINE(void, addDecl__lookups_1513)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, addDeclAt__lookups_995)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, importAllSymbols__importer_2054)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fromMod);
N_LIB_PRIVATE N_NIMCALL(void, addImport__importer_1458)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg* im);
N_LIB_PRIVATE N_NIMCALL(void, genericAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(void, incl__importer_1492)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* other);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_16)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__astalgo_3489)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(void, incl__pureZcollectionsZintsets_55)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(void, loadPackedSym__modulegraphs_8978)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg* s);
N_LIB_PRIVATE N_NIMCALL(void, addConverter__semdata_683)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg conv);
N_LIB_PRIVATE N_NIMCALL(void, addPattern__semdata_722)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg p);
N_LIB_PRIVATE N_NIMCALL(void, importPureEnumFields__importer_77)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* etyp);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_1441)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, initIdentIter__lookups_158)(tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A* ti, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* marked, tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg* im, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextIdentIter__lookups_278)(tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A* ti, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* marked, tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg* im, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(void, importPureEnumField__importer_69)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, afterImport__importer_4815)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m);
N_LIB_PRIVATE N_NIMCALL(NI*, X5BX5D___lookups_1101)(tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg* t, NI key);
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_2722)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m);
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_2710)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI module);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, initRodIterAllSyms__icZic_8670)(tyObject_RodIter__L6nv9cakjPARHk068AFo6ww* it, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI32 module, NIM_BOOL importHidden);
N_LIB_PRIVATE N_NIMCALL(void, incl__importer_240)(tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ* s, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextRodIter__icZic_8980)(tyObject_RodIter__L6nv9cakjPARHk068AFo6ww* it, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g);
N_LIB_PRIVATE N_NIMCALL(void, checkMinSonsLen__semdata_1114)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI length, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newSymNode__ast_3704)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, importAllSymbolsExcept__importer_1825)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fromMod, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* exceptSet);
N_LIB_PRIVATE N_NIMCALL(void, readExceptSet__importer_17)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, importSymbol__importer_1422)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fromMod, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* importSet);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, someSym__modulegraphs_2849)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name);
N_LIB_PRIVATE N_NIMCALL(void, errorUndeclaredIdentifier__lookups_2564)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* name, NimStringDesc* extra);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, initModuleIter__modulegraphs_2748)(tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A* mi, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name);
N_LIB_PRIVATE N_NIMCALL(void, rawImportSymbol__importer_119)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* origin, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* importSet);
static N_INLINE(NIM_BOOL, hasPattern__ast_4734)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
static N_INLINE(NIM_BOOL, isRoutine__ast_4677)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextModuleIter__modulegraphs_2783)(tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A* mi, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
STRING_LITERAL(TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_2, "as", 2);
extern TNimType NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTIobject__AMAna5nUcyswBmZhxx39baQ_;
extern TNimType NTIint__xHTZrq9aYs6boc9bCba0JbpQ_;
extern TNimType NTIpcontext__C5LQliQ3Detta8PpLynVjQ_;
N_LIB_PRIVATE TNimType NTItupleLnode58pnode_importhidden58boolT__hv7XYxzNv29cYlH39cwb529ag_;
extern TNimType NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_;
extern TNimType NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_;
N_LIB_PRIVATE TNimType NTIrefobject__mzsJbF13j9a1gF8FsVcBslA_;
extern TNimType NTItspecialword__N2XsqTpO5IzOf2KmXwk4Dw_;
N_LIB_PRIVATE TNimType NTIseqLtspecialwordT__s6XOb8vGaBHi7Py1r5uplQ_;
STRING_LITERAL(TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_5, "invalid pragma", 14);
STRING_LITERAL(TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_7, "/home/runner/work/nightlies/nightlies/nim/compiler/importer.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_6 = {((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_7),
((NI) 118),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_8 = {((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_7),
((NI) 119),
((NI) 14)}
;
STRING_LITERAL(TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_9, "invalid pragma, expected: ", 26);
static NIM_CONST tySet_tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_10 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x40}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_11 = {((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_7),
((NI) 260),
((NI) 23)}
;
extern TNimType NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_;
STRING_LITERAL(TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_14, "\012", 1);
STRING_LITERAL(TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_15, " imports ", 9);
STRING_LITERAL(TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_16, "module alias must be an identifier", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_17 = {((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_7),
((NI) 239),
((NI) 14)}
;
extern TNimType NTIseqLLpsym_tlineinfoTT__Jhh6ks9carRtwV9aOuM8yMNw_;
extern TNimType NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_;
STRING_LITERAL(TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_18, "module \'$1\' cannot import itself", 32);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_19 = {((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_7),
((NI) 299),
((NI) 16)}
;
STRING_LITERAL(TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_20, "; ", 2);
STRING_LITERAL(TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_21, " is deprecated", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_22 = {((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_7),
((NI) 303),
((NI) 13)}
;
extern TNimType NTIimportedmodule__ABXo2nVfMtcWNYv5zEiXDg_;
extern TNimType NTIpackedset__THXDbzJSs2hcC9a33en2pdw_;
extern TNimType NTIseqLimportedmoduleT__9boKiNhY9cnRQF2k9b9a9bGKbrA_;
STRING_LITERAL(TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_23, "rawImportSymbol", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_24 = {((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_7),
((NI) 57),
((NI) 19)}
;
STRING_LITERAL(TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_25, "unexpected pragma", 17);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_26 = {((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_7),
((NI) 128),
((NI) 15)}
;
STRING_LITERAL(TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_27, "importSymbol: 3", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_28 = {((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_7),
((NI) 144),
((NI) 48)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_29 = {((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_7),
((NI) 92),
((NI) 23)}
;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5228;
N_LIB_PRIVATE N_NIMCALL(void, declarePureEnumField__importer_61)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL amb;
	amb = NIM_FALSE;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T3_;
		T3_ = NIM_NIL;
		T3_ = someSymFromImportTable__lookups_561(c, (*s).name, (&amb));
		if (!(T3_ == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA4_;
		strTableAdd__astalgo_3325((&(*c).pureEnumFields), s);
	}
	LA4_: ;
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5319)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5281)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5324)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5275((&gch__system_5228.zct), c);
}
static N_INLINE(void, decRef__system_5326)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5324(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5281(src);
		incRef__system_5319(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5281((*dest));
		decRef__system_5326(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_NIMCALL(void, Marker_tyRef__mzsJbF13j9a1gF8FsVcBslA)(void* p, NI op) {
	tyObject_Env_importerdotnim_transformImportAs___AMAna5nUcyswBmZhxx39baQ* a;
	a = (tyObject_Env_importerdotnim_transformImportAs___AMAna5nUcyswBmZhxx39baQ*)p;
	nimGCvisit((void*)(*a).c1, op);
	nimGCvisit((void*)(*a).ret2.Field0, op);
	nimGCvisit((void*)(*a).n3, op);
}
static N_NIMCALL(void, Marker_tySequence__s6XOb8vGaBHi7Py1r5uplQ)(void* p, NI op) {
	tySequence__s6XOb8vGaBHi7Py1r5uplQ* a;
	NI T1_;
	a = (tySequence__s6XOb8vGaBHi7Py1r5uplQ*)p;
	T1_ = (NI)0;
}
N_LIB_PRIVATE N_NIMCALL(void, splitPragmas__importer_1365)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyTuple__HLgvPk0GVvUxspcAPY16vw* Result) {
	unsureAsgnRef((void**)&(*Result).Field0, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).Field1, NIM_NIL);
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 43))) goto LA3_;
		{
			NIM_BOOL T7_;
			NI T8_;
			T7_ = (NIM_BOOL)0;
			T8_ = (NI)0;
			T8_ = len__ast_3155(n);
			T7_ = (T8_ == ((NI) 2));
			if (!(T7_)) goto LA9_;
			T7_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 90));
			LA9_: ;
			if (!T7_) goto LA10_;
			unsureAsgnRef((void**) (&(*Result).Field0), (*n)._kind_6.sons->data[((NI) 0)]);
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ni;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* colontmp_;
				ni = NIM_NIL;
				colontmp_ = NIM_NIL;
				colontmp_ = (*n)._kind_6.sons->data[((NI) 1)];
				{
					NI i;
					NI colontmp__2;
					NI i_2;
					i = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__2 = safeLen__ast_3148(colontmp_);
					i_2 = ((NI) 0);
					{
						while (1) {
							if (!(i_2 < colontmp__2)) goto LA15;
							i = i_2;
							ni = (*colontmp_)._kind_6.sons->data[i];
							{
								tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw T20_;
								NI T21_;
								if (!((*ni).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2))) goto LA18_;
								T20_ = (tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw)0;
								T20_ = whichKeyword__idents_223((*ni)._kind_5.ident);
								unsureAsgnRef((void**) (&(*Result).Field1), (tySequence__s6XOb8vGaBHi7Py1r5uplQ*) incrSeqV3((TGenericSeq*)((*Result).Field1), (&NTIseqLtspecialwordT__s6XOb8vGaBHi7Py1r5uplQ_)));
								T21_ = (*Result).Field1->Sup.len++;
								(*Result).Field1->data[T21_] = T20_;
							}
							goto LA16_;
							LA18_: ;
							{
								liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_5), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_6, NIM_FALSE);
							}
							LA16_: ;
							i_2 += ((NI) 1);
						} LA15: ;
					}
				}
			}
		}
		goto LA5_;
		LA10_: ;
		{
			liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_5), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_8, NIM_FALSE);
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		unsureAsgnRef((void**) (&(*Result).Field0), n);
		{
			NI T27_;
			tyTuple__HLgvPk0GVvUxspcAPY16vw _;
			NI T30_;
			NI T31_;
			T27_ = (NI)0;
			T27_ = safeLen__ast_3148((*Result).Field0);
			if (!(((NI) 0) < T27_)) goto LA28_;
			nimZeroMem((void*)(&_), sizeof(tyTuple__HLgvPk0GVvUxspcAPY16vw));
			T30_ = (NI)0;
			T30_ = len__ast_3155((*Result).Field0);
			splitPragmas__importer_1365(c, (*(*Result).Field0)._kind_6.sons->data[(NI)(T30_ - ((NI) 1))], (&_));
			T31_ = (NI)0;
			T31_ = len__ast_3155((*Result).Field0);
			asgnRef((void**) (&(*(*Result).Field0)._kind_6.sons->data[(NI)(T31_ - ((NI) 1))]), _.Field0);
			genericSeqAssign((&(*Result).Field1), _.Field1, (&NTIseqLtspecialwordT__s6XOb8vGaBHi7Py1r5uplQ_));
		}
		LA28_: ;
	}
	LA1_: ;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_CLOSURE(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, processPragma__importer_4644)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n2, void* ClE_0) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_Env_importerdotnim_transformImportAs___AMAna5nUcyswBmZhxx39baQ* colonenvP_;
	tyTuple__HLgvPk0GVvUxspcAPY16vw T1_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result2;
	tySequence__s6XOb8vGaBHi7Py1r5uplQ* kws;
	result = NIM_NIL;
	colonenvP_ = (tyObject_Env_importerdotnim_transformImportAs___AMAna5nUcyswBmZhxx39baQ*) ClE_0;
	nimZeroMem((void*)(&T1_), sizeof(tyTuple__HLgvPk0GVvUxspcAPY16vw));
	splitPragmas__importer_1365((*colonenvP_).c1, n2, (&T1_));
	result2 = NIM_NIL;
	result2 = T1_.Field0;
	kws = NIM_NIL;
	kws = T1_.Field1;
	result = result2;
	{
		tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw* ai;
		NI i;
		NI L;
		NI T3_;
		ai = (tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw*)0;
		i = ((NI) 0);
		T3_ = (kws ? kws->Sup.len : 0);
		L = T3_;
		{
			while (1) {
				if (!(i < L)) goto LA5;
				ai = (&kws->data[i]);
				switch ((*ai)) {
				case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 294):
				{
					(*colonenvP_).ret2.Field1 = NIM_TRUE;
				}
				break;
				default:
				{
					NimStringDesc* T8_;
					NimStringDesc* T9_;
					T8_ = NIM_NIL;
					T9_ = NIM_NIL;
					T9_ = dollar___importer_4668(TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_10);
					T8_ = rawNewString((T9_ ? T9_->Sup.len : 0) + 26);
appendString(T8_, ((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_9));
appendString(T8_, T9_);
					liMessage__msgs_1128((*(*(*colonenvP_).c1).graph).config, (*(*colonenvP_).n3).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T8_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_11, NIM_FALSE);
				}
				break;
				}
				i += ((NI) 1);
			} LA5: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, transformImportAs__importer_4637)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyTuple__hv7XYxzNv29cYlH39cwb529ag* Result) {
	tyObject_Env_importerdotnim_transformImportAs___AMAna5nUcyswBmZhxx39baQ* colonenv_;
{	colonenv_ = NIM_NIL;
	colonenv_ = (tyObject_Env_importerdotnim_transformImportAs___AMAna5nUcyswBmZhxx39baQ*) newObj((&NTIrefobject__mzsJbF13j9a1gF8FsVcBslA_), sizeof(tyObject_Env_importerdotnim_transformImportAs___AMAna5nUcyswBmZhxx39baQ));
	(*colonenv_).Sup.m_type = (&NTIobject__AMAna5nUcyswBmZhxx39baQ_);
	asgnRef((void**) (&(*colonenv_).c1), c);
	asgnRef((void**) (&(*colonenv_).n3), n);
	nimZeroMem((void*)(&(*colonenv_).ret2), sizeof(tyTuple__hv7XYxzNv29cYlH39cwb529ag));
	{
		NIM_BOOL T3_;
		tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T5_;
		tyProc__TTCGJ1wsIRuN7Gfv9bQ89bYg T8_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T9_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*colonenv_).n3).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29));
		if (!(T3_)) goto LA4_;
		T5_ = NIM_NIL;
		T5_ = considerQuotedIdent__lookups_29((*colonenv_).c1, (*(*colonenv_).n3)._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		T3_ = eqStrings((*T5_).s, ((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_2));
		LA4_: ;
		if (!T3_) goto LA6_;
		asgnRef((void**) (&(*colonenv_).ret2.Field0), newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 78), (*(*colonenv_).n3).info));
		nimZeroMem((void*)(&T8_), sizeof(tyProc__TTCGJ1wsIRuN7Gfv9bQ89bYg));
		T8_.ClP_0 = processPragma__importer_4644; T8_.ClE_0 = colonenv_;
		T9_ = NIM_NIL;
		T9_ = T8_.ClE_0? T8_.ClP_0((*(*colonenv_).n3)._kind_6.sons->data[((NI) 1)], T8_.ClE_0):((TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_12)(T8_.ClP_0))((*(*colonenv_).n3)._kind_6.sons->data[((NI) 1)]);
		add__ast_4798((*colonenv_).ret2.Field0, T9_);
		add__ast_4798((*colonenv_).ret2.Field0, (*(*colonenv_).n3)._kind_6.sons->data[((NI) 2)]);
	}
	goto LA1_;
	LA6_: ;
	{
		tyProc__TTCGJ1wsIRuN7Gfv9bQ89bYg T11_;
		nimZeroMem((void*)(&T11_), sizeof(tyProc__TTCGJ1wsIRuN7Gfv9bQ89bYg));
		T11_.ClP_0 = processPragma__importer_4644; T11_.ClE_0 = colonenv_;
		asgnRef((void**) (&(*colonenv_).ret2.Field0), T11_.ClE_0? T11_.ClP_0((*colonenv_).n3, T11_.ClE_0):((TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_13)(T11_.ClP_0))((*colonenv_).n3));
	}
	LA1_: ;
	unsureAsgnRef((void**) (&(*Result).Field0), (*colonenv_).ret2.Field0);
	(*Result).Field1 = (*colonenv_).ret2.Field1;
	goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, find__importer_4766)(tySequence__48JTohSgTy339bRxHzUD8KA* a, NI32 item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NI32* i;
		NI i_2;
		NI L;
		NI T2_;
		i = (NI32*)0;
		i_2 = ((NI) 0);
		T2_ = (a ? a->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i_2 < L)) goto LA4;
				i = (&a->data[i_2]);
				{
					if (!((*i) == item)) goto LA7_;
					goto BeforeRet_;
				}
				LA7_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5281(p);
	decRef__system_5326(T1_);
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).symId += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).symId;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addUnique__importer_4621)(tySequence__qwqHTkRvwhrRyENtudHQ7g** x, NI y) {
	NI T9_;
{	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (((*x) ? (*x)->Sup.len : 0)-1);
		colontmp_ = T2_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA4;
				i = res;
				{
					if (!((*x)->data[i] == y)) goto LA7_;
					goto BeforeRet_;
				}
				LA7_: ;
				res += ((NI) 1);
			} LA4: ;
		}
	}
	unsureAsgnRef((void**) (&(*x)), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)((*x)), (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_)));
	T9_ = (*x)->Sup.len++;
	(*x)->data[T9_] = y;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, importModuleAs__importer_2174)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* realModule, NIM_BOOL importHidden) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg T24_;
	NI T25_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym100_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym101_;
	tySequence__qwqHTkRvwhrRyENtudHQ7g* T26_;
	tySequence__qwqHTkRvwhrRyENtudHQ7g** T27_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym126_;
	result = NIM_NIL;
	result = realModule;
	{
		if (!!(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 78)))) goto LA3_;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		NI T7_;
		T6_ = (NIM_BOOL)0;
		T7_ = (NI)0;
		T7_ = len__ast_3155(n);
		T6_ = !((T7_ == ((NI) 2)));
		if (T6_) goto LA8_;
		T6_ = !(((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2)));
		LA8_: ;
		if (!T6_) goto LA9_;
		liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_16), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_17, NIM_FALSE);
	}
	goto LA1_;
	LA9_: ;
	{
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T14_;
		if (!!(((*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_5.ident).id == (*(*realModule).name).id))) goto LA12_;
		T14_ = nextSymId__ast_3103((*c).Sup.idgen);
		result = createModuleAlias__ast_4069(realModule, T14_, (*(*n)._kind_6.sons->data[((NI) 1)])._kind_5.ident, (*n).info, (*(*(*c).graph).config).options);
	}
	goto LA1_;
	LA12_: ;
	LA1_: ;
	{
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T19_;
		if (!(result == realModule)) goto LA17_;
		T19_ = nextSymId__ast_3103((*c).Sup.idgen);
		result = createModuleAlias__ast_4069(realModule, T19_, (*realModule).name, (*n).info, (*(*(*c).graph).config).options);
	}
	LA17_: ;
	{
		if (!importHidden) goto LA22_;
		(*result).options |= ((NU32)1)<<((((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 27)) & 31);
	}
	LA22_: ;
	nimZeroMem((void*)(&T24_), sizeof(tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg));
	T24_.Field0 = result;
	T24_.Field1 = (*n).info;
	asgnRef((void**) (&(*c).unusedImports), (tySequence__Jhh6ks9carRtwV9aOuM8yMNw*) incrSeqV3((TGenericSeq*)((*c).unusedImports), (&NTIseqLLpsym_tlineinfoTT__Jhh6ks9carRtwV9aOuM8yMNw_)));
	T25_ = (*c).unusedImports->Sup.len++;
	asgnRef((void**) (&(*c).unusedImports->data[T25_].Field0), T24_.Field0);
	(*c).unusedImports->data[T25_].Field1 = T24_.Field1;
	xX60gensym100_ = result;
	xX60gensym101_ = realModule;
	X5BX5Deq___importer_2265((&(*c).importModuleMap), (NI)((NI)((NU64)(((NI) ((*xX60gensym100_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym100_).Sup.itemId.item))), (NI)((NI)((NU64)(((NI) ((*xX60gensym101_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym101_).Sup.itemId.item))));
	T26_ = NIM_NIL;
	T26_ = NIM_NIL;
	T27_ = (tySequence__qwqHTkRvwhrRyENtudHQ7g**)0;
	T27_ = mgetOrPut__importer_3448((&(*c).importModuleLookup), (*(*realModule).name).id, T26_);
	xX60gensym126_ = realModule;
	addUnique__importer_4621(T27_, (NI)((NI)((NU64)(((NI) ((*xX60gensym126_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym126_).Sup.itemId.item))));
	return result;
}
static N_INLINE(void, suggestSym__sigmatch_5404)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** usageSym, NIM_BOOL isDecl) {
	tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf;
	conf = (*g).config;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, myImportModule__importer_4755)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* importStmtResult) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyTuple__hv7XYxzNv29cYlH39cwb529ag transf;
	NI32 f;
	result = NIM_NIL;
	nimZeroMem((void*)(&transf), sizeof(tyTuple__hv7XYxzNv29cYlH39cwb529ag));
	transformImportAs__importer_4637(c, (*n), (&transf));
	unsureAsgnRef((void**) (&(*n)), transf.Field0);
	f = checkModuleName__modulepaths_21((*(*c).graph).config, (*n), NIM_TRUE);
	{
		NI L;
		NI T5_;
		NI recursion;
		NI T6_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* realModule;
		tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q* T22_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T38_;
		if (!!((f == ((NI32) -1)))) goto LA3_;
		addImportFileDep__semdata_641(c, f);
		T5_ = ((*(*c).graph).importStack ? (*(*c).graph).importStack->Sup.len : 0);
		L = T5_;
		recursion = find__importer_4766((*(*c).graph).importStack, f);
		asgnRef((void**) (&(*(*c).graph).importStack), (tySequence__48JTohSgTy339bRxHzUD8KA*) incrSeqV3((TGenericSeq*)((*(*c).graph).importStack), (&NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_)));
		T6_ = (*(*c).graph).importStack->Sup.len++;
		(*(*c).graph).importStack->data[T6_] = f;
		{
			NimStringDesc* err;
			NimStringDesc* T21_;
			if (!(((NI) 0) <= recursion)) goto LA9_;
			err = ((NimStringDesc*) NIM_NIL);
			{
				NI i;
				NI i_2;
				i = (NI)0;
				i_2 = recursion;
				{
					while (1) {
						NimStringDesc* T18_;
						NimStringDesc* T19_;
						NimStringDesc* T20_;
						if (!(i_2 < L)) goto LA13;
						i = i_2;
						{
							if (!(recursion < i)) goto LA16_;
							err = resizeString(err, 1);
appendString(err, ((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_14));
						}
						LA16_: ;
						T18_ = NIM_NIL;
						T19_ = NIM_NIL;
						T19_ = toFullPath__msgs_548((*(*c).graph).config, (*(*c).graph).importStack->data[i]);
						T20_ = NIM_NIL;
						T20_ = toFullPath__msgs_548((*(*c).graph).config, (*(*c).graph).importStack->data[(NI)(i + ((NI) 1))]);
						T18_ = rawNewString((T19_ ? T19_->Sup.len : 0) + (T20_ ? T20_->Sup.len : 0) + 9);
appendString(T18_, T19_);
appendString(T18_, ((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_15));
appendString(T18_, T20_);
						err = resizeString(err, (T18_ ? T18_->Sup.len : 0) + 0);
appendString(err, T18_);
						i_2 += ((NI) 1);
					} LA13: ;
				}
			}
			T21_ = NIM_NIL;
			T21_ = (*c).recursiveDep; (*c).recursiveDep = copyStringRC1(err);
			if (T21_) nimGCunrefNoCycle(T21_);
		}
		LA9_: ;
		realModule = NIM_NIL;
		T22_ = NIM_NIL;
		T22_ = pushOptionEntry__semdata_474(c);
		(void)(T22_);
		realModule = (*(*c).graph).importModuleCallback((*c).graph, (*c).module, f);
		result = importModuleAs__importer_2174(c, (*n), realModule, transf.Field1);
		popOptionEntry__semdata_489(c);
		asgnRef((void**) (&(*(*c).graph).importStack), (tySequence__48JTohSgTy339bRxHzUD8KA*) setLengthSeqV2(((*(*c).graph).importStack)?&((*(*c).graph).importStack)->Sup:NIM_NIL, (&NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_), ((NI) (L))));
		{
			NimStringDesc* T27_;
			if (!(realModule == (*c).module)) goto LA25_;
			T27_ = NIM_NIL;
			T27_ = nsuFormatSingleElem(((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_18), (*(*realModule).name).s);
			liMessage__msgs_1128((*(*c).graph).config, (*(*n)).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T27_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_19, NIM_FALSE);
		}
		LA25_: ;
		{
			NimStringDesc* prefix;
			NimStringDesc* T37_;
			if (!(((*realModule).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 22))&63U)))!=0)) goto LA30_;
			prefix = ((NimStringDesc*) NIM_NIL);
			{
				NimStringDesc* T36_;
				if (!!(((*realModule).constraint == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA34_;
				T36_ = NIM_NIL;
				T36_ = rawNewString(((*(*realModule).constraint)._kind_3.strVal ? (*(*realModule).constraint)._kind_3.strVal->Sup.len : 0) + 2);
appendString(T36_, (*(*realModule).constraint)._kind_3.strVal);
appendString(T36_, ((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_20));
				prefix = T36_;
			}
			LA34_: ;
			T37_ = NIM_NIL;
			T37_ = rawNewString((prefix ? prefix->Sup.len : 0) + ((*(*realModule).name).s ? (*(*realModule).name).s->Sup.len : 0) + 14);
appendString(T37_, prefix);
appendString(T37_, (*(*realModule).name).s);
appendString(T37_, ((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_21));
			liMessage__msgs_1128((*(*c).graph).config, (*(*n)).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 21), T37_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_22, NIM_FALSE);
		}
		LA30_: ;
		suggestSym__sigmatch_5404((*c).graph, (*(*n)).info, result, &(*(*c).graph).usageSym, NIM_FALSE);
		T38_ = NIM_NIL;
		T38_ = newSymNode__ast_3707(result, (*(*n)).info);
		add__ast_4798(importStmtResult, T38_);
	}
	LA3_: ;
	return result;
}
static N_INLINE(void, addDecl__lookups_1513)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	addDeclAt__lookups_995(c, (*c).currentScope, sym, info);
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result) {
	initPackedSet__pureZcollectionsZintsets_16(Result);
}
N_LIB_PRIVATE N_NIMCALL(void, addImport__importer_1458)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg* im) {
	NI T47_;
{	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (((*c).imports ? (*c).imports->Sup.len : 0)-1);
		colontmp_ = T2_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA4;
				i = res;
				{
					if (!((*c).imports->data[i].m == (*im).m)) goto LA7_;
					switch ((*c).imports->data[i].mode) {
					case ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 0):
					{
					}
					break;
					case ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 1):
					{
						switch ((*im).mode) {
						case ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 0):
						case ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 2):
						{
							genericAssign((void*)(&(*c).imports->data[i]), (void*)im, (&NTIimportedmodule__ABXo2nVfMtcWNYv5zEiXDg_));
						}
						break;
						case ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 1):
						{
							incl__importer_1492((&(*c).imports->data[i]._mode_2.imported), (&(*im)._mode_2.imported));
						}
						break;
						}
					}
					break;
					case ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 2):
					{
						switch ((*im).mode) {
						case ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 0):
						{
							genericAssign((void*)(&(*c).imports->data[i]), (void*)im, (&NTIimportedmodule__ABXo2nVfMtcWNYv5zEiXDg_));
						}
						break;
						case ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 1):
						{
						}
						break;
						case ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 2):
						{
							tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw cut;
							nimZeroMem((void*)(&cut), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
							initIntSet__pureZcollectionsZintsets_238((&cut));
							{
								NI j;
								tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw colontmp__2;
								j = (NI)0;
								nimZeroMem((void*)(&colontmp__2), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
								nimCopyMem((void*)(&colontmp__2), (NIM_CONST void*)(&(*im)._mode_3.exceptSet), sizeof(colontmp__2));
								{
									if (!(colontmp__2.elems <= ((NI) 34))) goto LA20_;
									{
										NI i_2;
										NI i_3;
										i_2 = (NI)0;
										i_3 = ((NI) 0);
										{
											while (1) {
												if (!(i_3 < colontmp__2.elems)) goto LA24;
												i_2 = i_3;
												j = colontmp__2.a[(i_2)- 0];
												{
													NIM_BOOL T27_;
													T27_ = (NIM_BOOL)0;
													T27_ = contains__astalgo_3489((&(*c).imports->data[i]._mode_3.exceptSet), j);
													if (!T27_) goto LA28_;
													incl__pureZcollectionsZintsets_55((&cut), j);
												}
												LA28_: ;
												i_3 += ((NI) 1);
											} LA24: ;
										}
									}
								}
								goto LA18_;
								LA20_: ;
								{
									tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* r;
									r = colontmp__2.head;
									{
										while (1) {
											NI i_4;
											if (!!((r == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA32;
											i_4 = ((NI) 0);
											{
												while (1) {
													NU w;
													NI j_2;
													if (!(i_4 <= ((NI) 7))) goto LA34;
													w = (*r).bits[(i_4)- 0];
													j_2 = ((NI) 0);
													{
														while (1) {
															if (!!((w == ((NU) 0)))) goto LA36;
															{
																NI T41_;
																if (!!(((NU)(w & ((NU) 1)) == ((NU) 0)))) goto LA39_;
																T41_ = (NI)0;
																T41_ = pluspercent___system_696((NI)((NU64)(i_4) << (NU64)(((NI) 6))), j_2);
																j = (NI)((NI)((NU64)((*r).key) << (NU64)(((NI) 9))) | T41_);
																{
																	NIM_BOOL T44_;
																	T44_ = (NIM_BOOL)0;
																	T44_ = contains__astalgo_3489((&(*c).imports->data[i]._mode_3.exceptSet), j);
																	if (!T44_) goto LA45_;
																	incl__pureZcollectionsZintsets_55((&cut), j);
																}
																LA45_: ;
															}
															LA39_: ;
															j_2 += ((NI) 1);
															w = (NU)((NU64)(w) >> (NU64)(((NI) 1)));
														} LA36: ;
													}
													i_4 += ((NI) 1);
												} LA34: ;
											}
											r = (*r).next;
										} LA32: ;
									}
								}
								LA18_: ;
							}
							genericAssign((void*)(&(*c).imports->data[i]._mode_3.exceptSet), (void*)(&cut), (&NTIpackedset__THXDbzJSs2hcC9a33en2pdw_));
						}
						break;
						}
					}
					break;
					}
					goto BeforeRet_;
				}
				LA7_: ;
				res += ((NI) 1);
			} LA4: ;
		}
	}
	asgnRef((void**) (&(*c).imports), (tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA*) incrSeqV3((TGenericSeq*)((*c).imports), (&NTIseqLimportedmoduleT__9boKiNhY9cnRQF2k9b9a9bGKbrA_)));
	T47_ = (*c).imports->Sup.len++;
	genericAssign((void*)(&(*c).imports->data[T47_]), (void*)im, (&NTIimportedmodule__ABXo2nVfMtcWNYv5zEiXDg_));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, importPureEnumField__importer_69)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL amb;
	amb = NIM_FALSE;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T3_;
		T3_ = NIM_NIL;
		T3_ = someSymFromImportTable__lookups_561(c, (*s).name, (&amb));
		if (!(T3_ == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA4_;
		strTableAdd__astalgo_3325((&(*c).pureEnumFields), s);
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, importPureEnumFields__importer_77)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* etyp) {
	{
		NI j;
		NI colontmp_;
		NI i;
		j = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155((*etyp).n);
		i = ((NI) 0);
		{
			while (1) {
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* e;
				if (!(i < colontmp_)) goto LA3;
				j = i;
				e = (*(*(*etyp).n)._kind_6.sons->data[j])._kind_4.sym;
				{
					if (!!(((*e).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 20)))) goto LA6_;
					internalErrorImpl__msgs_1441((*(*c).graph).config, (*s).info, ((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_23), TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_24);
				}
				LA6_: ;
				{
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* check;
					tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw marked;
					check = NIM_NIL;
					nimZeroMem((void*)(&marked), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
					initIntSet__pureZcollectionsZintsets_238((&marked));
					{
						tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg* im;
						NI i_2;
						NI L;
						NI T10_;
						im = (tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg*)0;
						i_2 = ((NI) 0);
						T10_ = ((*c).imports ? (*c).imports->Sup.len : 0);
						L = T10_;
						{
							while (1) {
								if (!(i_2 < L)) goto LA12;
								im = (&(*c).imports->data[i_2]);
								{
									tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s_2;
									tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A ti;
									tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* candidate;
									s_2 = NIM_NIL;
									nimZeroMem((void*)(&ti), sizeof(tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A));
									candidate = initIdentIter__lookups_158((&ti), (&marked), (&(*im)), (*e).name, (*c).graph);
									{
										while (1) {
											if (!!((candidate == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA15;
											s_2 = candidate;
											check = s_2;
											{
												tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym12_;
												tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym13_;
												xX60gensym12_ = check;
												xX60gensym13_ = e;
												if (!((NI)((NI)((NU64)(((NI) ((*xX60gensym12_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym12_).Sup.itemId.item))) == (NI)((NI)((NU64)(((NI) ((*xX60gensym13_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym13_).Sup.itemId.item))))) goto LA18_;
												e = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
												goto LA8;
											}
											LA18_: ;
											candidate = nextIdentIter__lookups_278((&ti), (&marked), (&(*im)), (*c).graph);
										} LA15: ;
									}
								}
								i_2 += ((NI) 1);
							} LA12: ;
						}
					}
				} LA8: ;
				{
					if (!!((e == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA22_;
					importPureEnumField__importer_69(c, e);
				}
				LA22_: ;
				i += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, importAllSymbols__importer_2054)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fromMod) {
	tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg T1_;
	nimZeroMem((void*)(&T1_), sizeof(tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg));
	T1_.m = fromMod;
	T1_.mode = ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 0);
	addImport__importer_1458(c, (&T1_));
	{
		tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg* it;
		NI i;
		NI L;
		NI T3_;
		it = (tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg*)0;
		i = ((NI) 0);
		T3_ = ((*(*c).graph).ifaces->data[(*fromMod).position].converters ? (*(*c).graph).ifaces->data[(*fromMod).position].converters->Sup.len : 0);
		L = T3_;
		{
			while (1) {
				if (!(i < L)) goto LA5;
				it = (&(*(*c).graph).ifaces->data[(*fromMod).position].converters->data[i]);
				{
					if (!NIM_TRUE) goto LA8_;
					loadPackedSym__modulegraphs_8978((*c).graph, it);
					{
						if (!(((*(*it).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 1))&63U)))!=0)) goto LA12_;
						addConverter__semdata_683(c, (*it));
					}
					LA12_: ;
				}
				LA8_: ;
				i += ((NI) 1);
			} LA5: ;
		}
	}
	{
		tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg* it_2;
		NI i_2;
		NI L_2;
		NI T15_;
		it_2 = (tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg*)0;
		i_2 = ((NI) 0);
		T15_ = ((*(*c).graph).ifaces->data[(*fromMod).position].patterns ? (*(*c).graph).ifaces->data[(*fromMod).position].patterns->Sup.len : 0);
		L_2 = T15_;
		{
			while (1) {
				if (!(i_2 < L_2)) goto LA17;
				it_2 = (&(*(*c).graph).ifaces->data[(*fromMod).position].patterns->data[i_2]);
				{
					if (!NIM_TRUE) goto LA20_;
					loadPackedSym__modulegraphs_8978((*c).graph, it_2);
					{
						if (!(((*(*it_2).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 1))&63U)))!=0)) goto LA24_;
						addPattern__semdata_722(c, (*it_2));
					}
					LA24_: ;
				}
				LA20_: ;
				i_2 += ((NI) 1);
			} LA17: ;
		}
	}
	{
		tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg* it_3;
		NI i_3;
		NI L_3;
		NI T27_;
		it_3 = (tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg*)0;
		i_3 = ((NI) 0);
		T27_ = ((*(*c).graph).ifaces->data[(*fromMod).position].pureEnums ? (*(*c).graph).ifaces->data[(*fromMod).position].pureEnums->Sup.len : 0);
		L_3 = T27_;
		{
			while (1) {
				if (!(i_3 < L_3)) goto LA29;
				it_3 = (&(*(*c).graph).ifaces->data[(*fromMod).position].pureEnums->data[i_3]);
				{
					if (!NIM_TRUE) goto LA32_;
					loadPackedSym__modulegraphs_8978((*c).graph, it_3);
					importPureEnumFields__importer_77(c, (*it_3).sym, (*(*it_3).sym).typ);
				}
				LA32_: ;
				i_3 += ((NI) 1);
			} LA29: ;
		}
	}
}
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_2710)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI module) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = ((*g).packed_0 ? (*g).packed_0->Sup.len : 0);
	T1_ = (module < T2_);
	if (!(T1_)) goto LA3_;
	T1_ = ((*g).packed_0->data[module].status == ((tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg) 3));
	LA3_: ;
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_2722)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = isCachedModule__modulegraphs_2710(g, (*m).position);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, afterImport__importer_4815)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m) {
	NI realModuleId;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym149_;
	NI* T1_;
	xX60gensym149_ = m;
	T1_ = (NI*)0;
	T1_ = X5BX5D___lookups_1101((&(*c).importModuleMap), (NI)((NI)((NU64)(((NI) ((*xX60gensym149_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym149_).Sup.itemId.item))));
	realModuleId = (*T1_);
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
		NIM_BOOL importHidden;
		s = NIM_NIL;
		importHidden = (((*m).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 27))&31U)))!=0);
		{
			NIM_BOOL T5_;
			tyObject_RodIter__L6nv9cakjPARHk068AFo6ww rodIt;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* r;
			T5_ = (NIM_BOOL)0;
			T5_ = isCachedModule__modulegraphs_2722((*c).graph, m);
			if (!T5_) goto LA6_;
			nimZeroMem((void*)(&rodIt), sizeof(tyObject_RodIter__L6nv9cakjPARHk068AFo6ww));
			r = initRodIterAllSyms__icZic_8670((&rodIt), (*(*c).graph).config, (*(*c).graph).cache, (&(*(*c).graph).packed_0), ((NI32) ((*m).position)), importHidden);
			{
				while (1) {
					if (!!((r == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA9;
					s = r;
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym151_;
						tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ T14_;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym152_;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym153_;
						xX60gensym151_ = (*s).owner;
						if (!!(((NI)((NI)((NU64)(((NI) ((*xX60gensym151_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym151_).Sup.itemId.item))) == realModuleId))) goto LA12_;
						xX60gensym152_ = m;
						T14_.Field0 = (NI)((NI)((NU64)(((NI) ((*xX60gensym152_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym152_).Sup.itemId.item)));
						xX60gensym153_ = s;
						T14_.Field1 = (NI)((NI)((NU64)(((NI) ((*xX60gensym153_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym153_).Sup.itemId.item)));
						incl__importer_240((&(*c).exportIndirections), T14_);
					}
					LA12_: ;
					r = nextRodIter__icZic_8980((&rodIt), (&(*(*c).graph).packed_0));
				} LA9: ;
			}
		}
		goto LA3_;
		LA6_: ;
		{
			{
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** s_2;
				tySequence__ed0C0uAUZPhvw3RAc5hfYg* colontmp_;
				tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* retX60gensym17_;
				NI i;
				NI L;
				NI T21_;
				s_2 = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**)0;
				colontmp_ = NIM_NIL;
				retX60gensym17_ = (&(*(*c).graph).ifaces->data[(*m).position].interf);
				{
					if (!importHidden) goto LA19_;
					retX60gensym17_ = (&(*(*c).graph).ifaces->data[(*m).position].interfHidden);
				}
				LA19_: ;
				colontmp_ = (*retX60gensym17_).data;
				i = ((NI) 0);
				T21_ = (colontmp_ ? colontmp_->Sup.len : 0);
				L = T21_;
				{
					while (1) {
						if (!(i < L)) goto LA23;
						s_2 = &colontmp_->data[i];
						{
							if (!!(((*s_2) == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA26_;
							s = (*s_2);
							{
								tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym151__2;
								tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ T32_;
								tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym152__2;
								tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym153__2;
								xX60gensym151__2 = (*s).owner;
								if (!!(((NI)((NI)((NU64)(((NI) ((*xX60gensym151__2).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym151__2).Sup.itemId.item))) == realModuleId))) goto LA30_;
								xX60gensym152__2 = m;
								T32_.Field0 = (NI)((NI)((NU64)(((NI) ((*xX60gensym152__2).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym152__2).Sup.itemId.item)));
								xX60gensym153__2 = s;
								T32_.Field1 = (NI)((NI)((NU64)(((NI) ((*xX60gensym153__2).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym153__2).Sup.itemId.item)));
								incl__importer_240((&(*c).exportIndirections), T32_);
							}
							LA30_: ;
						}
						LA26_: ;
						i += ((NI) 1);
					} LA23: ;
				}
			}
		}
		LA3_: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, impMod__importer_4966)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* importStmtResult) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it_2;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m;
	it_2 = it;
	m = myImportModule__importer_4755(c, &it_2, importStmtResult);
	{
		if (!!((m == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA3_;
		addDecl__lookups_1513(c, m, (*it_2).info);
		importAllSymbols__importer_2054(c, m);
		afterImport__importer_4815(c, m);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, evalImport__importer_4976)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 116), (*n).info);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				{
					NIM_BOOL T6_;
					NI T8_;
					NI lastPos;
					NI T11_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* imp;
					NI T12_;
					T6_ = (NIM_BOOL)0;
					T6_ = ((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30));
					if (!(T6_)) goto LA7_;
					T8_ = (NI)0;
					T8_ = len__ast_3155(it);
					T6_ = ((*(*it)._kind_6.sons->data[(NI)(T8_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41));
					LA7_: ;
					if (!T6_) goto LA9_;
					T11_ = (NI)0;
					T11_ = len__ast_3155(it);
					lastPos = (NI)(T11_ - ((NI) 1));
					imp = copyNode__ast_4324(it);
					T12_ = (NI)0;
					T12_ = len__ast_3155(it);
					newSons__semtypinst_416(imp, T12_);
					{
						NI i_3;
						NI i_4;
						i_3 = (NI)0;
						i_4 = ((NI) 0);
						{
							while (1) {
								if (!(i_4 < lastPos)) goto LA15;
								i_3 = i_4;
								asgnRef((void**) (&(*imp)._kind_6.sons->data[i_3]), (*it)._kind_6.sons->data[i_3]);
								i_4 += ((NI) 1);
							} LA15: ;
						}
					}
					asgnRef((void**) (&(*imp)._kind_6.sons->data[lastPos]), (*imp)._kind_6.sons->data[((NI) 0)]);
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* colontmp__2;
						x = NIM_NIL;
						colontmp__2 = NIM_NIL;
						colontmp__2 = (*it)._kind_6.sons->data[lastPos];
						{
							NI i_5;
							NI colontmp__3;
							NI i_6;
							i_5 = (NI)0;
							colontmp__3 = (NI)0;
							colontmp__3 = safeLen__ast_3148(colontmp__2);
							i_6 = ((NI) 0);
							{
								while (1) {
									if (!(i_6 < colontmp__3)) goto LA19;
									i_5 = i_6;
									x = (*colontmp__2)._kind_6.sons->data[i_5];
									{
										NIM_BOOL T22_;
										tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* impAs;
										T22_ = (NIM_BOOL)0;
										T22_ = ((*x).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29));
										if (!(T22_)) goto LA23_;
										T22_ = eqStrings((*(*(*x)._kind_6.sons->data[((NI) 0)])._kind_5.ident).s, ((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_2));
										LA23_: ;
										if (!T22_) goto LA24_;
										impAs = copyNode__ast_4324(x);
										newSons__semtypinst_416(impAs, ((NI) 3));
										asgnRef((void**) (&(*impAs)._kind_6.sons->data[((NI) 0)]), (*x)._kind_6.sons->data[((NI) 0)]);
										asgnRef((void**) (&(*imp)._kind_6.sons->data[lastPos]), (*x)._kind_6.sons->data[((NI) 1)]);
										asgnRef((void**) (&(*impAs)._kind_6.sons->data[((NI) 1)]), imp);
										asgnRef((void**) (&(*impAs)._kind_6.sons->data[((NI) 2)]), (*x)._kind_6.sons->data[((NI) 2)]);
										impMod__importer_4966(c, impAs, result);
									}
									goto LA20_;
									LA24_: ;
									{
										asgnRef((void**) (&(*imp)._kind_6.sons->data[lastPos]), x);
										impMod__importer_4966(c, imp, result);
									}
									LA20_: ;
									i_6 += ((NI) 1);
								} LA19: ;
							}
						}
					}
				}
				goto LA4_;
				LA9_: ;
				{
					impMod__importer_4966(c, it, result);
				}
				LA4_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, importAllSymbolsExcept__importer_1825)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fromMod, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* exceptSet) {
	tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg T1_;
	nimZeroMem((void*)(&T1_), sizeof(tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg));
	T1_.m = fromMod;
	T1_.mode = ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 2);
	genericAssign((void*)(&T1_._mode_3.exceptSet), (void*)exceptSet, (&NTIpackedset__THXDbzJSs2hcC9a33en2pdw_));
	addImport__importer_1458(c, (&T1_));
	{
		tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg* it;
		NI i;
		NI L;
		NI T3_;
		it = (tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg*)0;
		i = ((NI) 0);
		T3_ = ((*(*c).graph).ifaces->data[(*fromMod).position].converters ? (*(*c).graph).ifaces->data[(*fromMod).position].converters->Sup.len : 0);
		L = T3_;
		{
			while (1) {
				if (!(i < L)) goto LA5;
				it = (&(*(*c).graph).ifaces->data[(*fromMod).position].converters->data[i]);
				{
					NIM_BOOL T8_;
					T8_ = (NIM_BOOL)0;
					T8_ = contains__astalgo_3489(exceptSet, (*(*(*it).sym).name).id);
					if (!!(T8_)) goto LA9_;
					loadPackedSym__modulegraphs_8978((*c).graph, it);
					{
						if (!(((*(*it).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 1))&63U)))!=0)) goto LA13_;
						addConverter__semdata_683(c, (*it));
					}
					LA13_: ;
				}
				LA9_: ;
				i += ((NI) 1);
			} LA5: ;
		}
	}
	{
		tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg* it_2;
		NI i_2;
		NI L_2;
		NI T16_;
		it_2 = (tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg*)0;
		i_2 = ((NI) 0);
		T16_ = ((*(*c).graph).ifaces->data[(*fromMod).position].patterns ? (*(*c).graph).ifaces->data[(*fromMod).position].patterns->Sup.len : 0);
		L_2 = T16_;
		{
			while (1) {
				if (!(i_2 < L_2)) goto LA18;
				it_2 = (&(*(*c).graph).ifaces->data[(*fromMod).position].patterns->data[i_2]);
				{
					NIM_BOOL T21_;
					T21_ = (NIM_BOOL)0;
					T21_ = contains__astalgo_3489(exceptSet, (*(*(*it_2).sym).name).id);
					if (!!(T21_)) goto LA22_;
					loadPackedSym__modulegraphs_8978((*c).graph, it_2);
					{
						if (!(((*(*it_2).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 1))&63U)))!=0)) goto LA26_;
						addPattern__semdata_722(c, (*it_2));
					}
					LA26_: ;
				}
				LA22_: ;
				i_2 += ((NI) 1);
			} LA18: ;
		}
	}
	{
		tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg* it_3;
		NI i_3;
		NI L_3;
		NI T29_;
		it_3 = (tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg*)0;
		i_3 = ((NI) 0);
		T29_ = ((*(*c).graph).ifaces->data[(*fromMod).position].pureEnums ? (*(*c).graph).ifaces->data[(*fromMod).position].pureEnums->Sup.len : 0);
		L_3 = T29_;
		{
			while (1) {
				if (!(i_3 < L_3)) goto LA31;
				it_3 = (&(*(*c).graph).ifaces->data[(*fromMod).position].pureEnums->data[i_3]);
				{
					NIM_BOOL T34_;
					T34_ = (NIM_BOOL)0;
					T34_ = contains__astalgo_3489(exceptSet, (*(*(*it_3).sym).name).id);
					if (!!(T34_)) goto LA35_;
					loadPackedSym__modulegraphs_8978((*c).graph, it_3);
					importPureEnumFields__importer_77(c, (*it_3).sym, (*(*it_3).sym).typ);
				}
				LA35_: ;
				i_3 += ((NI) 1);
			} LA31: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, readExceptSet__importer_17)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result) {
	initIntSet__pureZcollectionsZintsets_238(Result);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				ident = considerQuotedIdent__lookups_29(c, (*n)._kind_6.sons->data[i], ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
				incl__pureZcollectionsZintsets_55(Result, (*ident).id);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, evalImportExcept__importer_5070)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m;
	result = NIM_NIL;
	result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 116), (*n).info);
	checkMinSonsLen__semdata_1114(n, ((NI) 2), (*(*c).graph).config);
	m = myImportModule__importer_4755(c, &(*n)._kind_6.sons->data[((NI) 0)], result);
	{
		tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw T5_;
		if (!!((m == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA3_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), newSymNode__ast_3704(m));
		addDecl__lookups_1513(c, m, (*n).info);
		nimZeroMem((void*)(&T5_), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
		readExceptSet__importer_17(c, n, (&T5_));
		importAllSymbolsExcept__importer_1825(c, m, (&T5_));
		afterImport__importer_4815(c, m);
	}
	LA3_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isRoutine__ast_4677)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((520192 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
	return result;
}
static N_INLINE(NIM_BOOL, hasPattern__ast_4734)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = isRoutine__ast_4677(s);
	if (!(T1_)) goto LA2_;
	T1_ = !(((*(*(*s).ast)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawImportSymbol__importer_119)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* origin, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* importSet) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym15_;
	xX60gensym15_ = s;
	incl__pureZcollectionsZintsets_55(importSet, (NI)((NI)((NU64)(((NI) ((*xX60gensym15_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym15_).Sup.itemId.item))));
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* etyp;
		if (!((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7))) goto LA3_;
		etyp = (*s).typ;
		{
			if (!((*etyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1) || (*etyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14))) goto LA7_;
			{
				NI j;
				NI colontmp_;
				NI i;
				j = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_3155((*etyp).n);
				i = ((NI) 0);
				{
					while (1) {
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* e;
						if (!(i < colontmp_)) goto LA11;
						j = i;
						e = (*(*(*etyp).n)._kind_6.sons->data[j])._kind_4.sym;
						{
							if (!!(((*e).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 20)))) goto LA14_;
							internalErrorImpl__msgs_1441((*(*c).graph).config, (*s).info, ((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_23), TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_29);
						}
						LA14_: ;
						{
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* check;
							tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw marked;
							check = NIM_NIL;
							nimZeroMem((void*)(&marked), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
							initIntSet__pureZcollectionsZintsets_238((&marked));
							{
								tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg* im;
								NI i_2;
								NI L;
								NI T18_;
								im = (tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg*)0;
								i_2 = ((NI) 0);
								T18_ = ((*c).imports ? (*c).imports->Sup.len : 0);
								L = T18_;
								{
									while (1) {
										if (!(i_2 < L)) goto LA20;
										im = (&(*c).imports->data[i_2]);
										{
											tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s_2;
											tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A ti;
											tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* candidate;
											s_2 = NIM_NIL;
											nimZeroMem((void*)(&ti), sizeof(tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A));
											candidate = initIdentIter__lookups_158((&ti), (&marked), (&(*im)), (*e).name, (*c).graph);
											{
												while (1) {
													if (!!((candidate == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA23;
													s_2 = candidate;
													check = s_2;
													{
														tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym22_;
														tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym23_;
														xX60gensym22_ = check;
														xX60gensym23_ = e;
														if (!((NI)((NI)((NU64)(((NI) ((*xX60gensym22_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym22_).Sup.itemId.item))) == (NI)((NI)((NU64)(((NI) ((*xX60gensym23_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym23_).Sup.itemId.item))))) goto LA26_;
														e = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
														goto LA16;
													}
													LA26_: ;
													candidate = nextIdentIter__lookups_278((&ti), (&marked), (&(*im)), (*c).graph);
												} LA23: ;
											}
										}
										i_2 += ((NI) 1);
									} LA20: ;
								}
							}
						} LA16: ;
						{
							if (!!((e == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA30_;
							{
								if (!!((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 11))&63U)))!=0))) goto LA34_;
								rawImportSymbol__importer_119(c, e, origin, importSet);
							}
							goto LA32_;
							LA34_: ;
							{
								importPureEnumField__importer_69(c, e);
							}
							LA32_: ;
						}
						LA30_: ;
						i += ((NI) 1);
					} LA11: ;
				}
			}
		}
		LA7_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		{
			tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg T42_;
			if (!((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 16))) goto LA40_;
			nimZeroMem((void*)(&T42_), sizeof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg));
			nimZeroMem((void*)(&T42_), sizeof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg));
			T42_.sym = s;
			addConverter__semdata_683(c, T42_);
		}
		LA40_: ;
		{
			NIM_BOOL T45_;
			tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg T48_;
			T45_ = (NIM_BOOL)0;
			T45_ = hasPattern__ast_4734(s);
			if (!T45_) goto LA46_;
			nimZeroMem((void*)(&T48_), sizeof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg));
			nimZeroMem((void*)(&T48_), sizeof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg));
			T48_.sym = s;
			addPattern__semdata_722(c, T48_);
		}
		LA46_: ;
	}
	LA1_: ;
	{
		tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ T53_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym27_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym28_;
		if (!!(((*s).owner == origin))) goto LA51_;
		xX60gensym27_ = origin;
		T53_.Field0 = (NI)((NI)((NU64)(((NI) ((*xX60gensym27_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym27_).Sup.itemId.item)));
		xX60gensym28_ = s;
		T53_.Field1 = (NI)((NI)((NU64)(((NI) ((*xX60gensym28_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym28_).Sup.itemId.item)));
		incl__importer_240((&(*c).exportIndirections), T53_);
	}
	LA51_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, importSymbol__importer_1422)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fromMod, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* importSet) {
	tyTuple__HLgvPk0GVvUxspcAPY16vw T1_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n_2;
	tySequence__s6XOb8vGaBHi7Py1r5uplQ* kws;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
	nimZeroMem((void*)(&T1_), sizeof(tyTuple__HLgvPk0GVvUxspcAPY16vw));
	splitPragmas__importer_1365(c, n, (&T1_));
	n_2 = NIM_NIL;
	n_2 = T1_.Field0;
	kws = NIM_NIL;
	kws = T1_.Field1;
	{
		NI T4_;
		T4_ = (kws ? kws->Sup.len : 0);
		if (!(((NI) 0) < T4_)) goto LA5_;
		liMessage__msgs_1128((*(*c).graph).config, (*n_2).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_25), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_26, NIM_FALSE);
	}
	LA5_: ;
	ident = considerQuotedIdent__lookups_29(c, n_2, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
	s = someSym__modulegraphs_2849((*c).graph, fromMod, ident);
	{
		if (!(s == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA9_;
		errorUndeclaredIdentifier__lookups_2564(c, (*n_2).info, (*ident).s, ((NimStringDesc*) NIM_NIL));
	}
	goto LA7_;
	LA9_: ;
	{
		NIM_BOOL multiImport;
		NIM_BOOL T12_;
		T12_ = (NIM_BOOL)0;
		T12_ = !(((43513728 &((NU32)1<<((NU)((*s).kind)&31U)))!=0));
		if (T12_) goto LA13_;
		T12_ = ((520192 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
		LA13_: ;
		multiImport = T12_;
		{
			tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A it;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* e;
			if (!multiImport) goto LA16_;
			nimZeroMem((void*)(&it), sizeof(tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A));
			e = initModuleIter__modulegraphs_2748((&it), (*c).graph, fromMod, (*s).name);
			{
				while (1) {
					if (!!((e == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA19;
					{
						if (!!(((*(*e).name).id == (*(*s).name).id))) goto LA22_;
						internalErrorImpl__msgs_1441((*(*c).graph).config, (*n_2).info, ((NimStringDesc*) &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_27), TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_28);
					}
					LA22_: ;
					{
						if (!((43513728 &((NU32)1<<((NU)((*s).kind)&31U)))!=0)) goto LA26_;
						rawImportSymbol__importer_119(c, e, fromMod, importSet);
					}
					LA26_: ;
					e = nextModuleIter__modulegraphs_2783((&it), (*c).graph);
				} LA19: ;
			}
		}
		goto LA14_;
		LA16_: ;
		{
			rawImportSymbol__importer_119(c, s, fromMod, importSet);
		}
		LA14_: ;
		suggestSym__sigmatch_5404((*c).graph, (*n_2).info, s, &(*(*c).graph).usageSym, NIM_FALSE);
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, evalFrom__importer_5044)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m;
	result = NIM_NIL;
	result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 116), (*n).info);
	checkMinSonsLen__semdata_1114(n, ((NI) 2), (*(*c).graph).config);
	m = myImportModule__importer_4755(c, &(*n)._kind_6.sons->data[((NI) 0)], result);
	{
		tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg im;
		if (!!((m == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA3_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), newSymNode__ast_3704(m));
		addDecl__lookups_1513(c, m, (*n).info);
		nimZeroMem((void*)(&im), sizeof(tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg));
		nimZeroMem((void*)(&im), sizeof(tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg));
		im.m = m;
		im.mode = ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 1);
		initIntSet__pureZcollectionsZintsets_238((&im._mode_2.imported));
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 1);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA7;
					i = i_2;
					{
						if (!!(((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23)))) goto LA10_;
						importSymbol__importer_1422(c, (*n)._kind_6.sons->data[i], m, (&im._mode_2.imported));
					}
					LA10_: ;
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
		addImport__importer_1458(c, (&im));
		afterImport__importer_4815(c, m);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, atmimporterdotnim_DatInit000)(void) {
static TNimNode* TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_3_4[4];
static TNimNode* TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_4_2[2];
static TNimNode TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[8];
NTIobject__AMAna5nUcyswBmZhxx39baQ_.size = sizeof(tyObject_Env_importerdotnim_transformImportAs___AMAna5nUcyswBmZhxx39baQ);
NTIobject__AMAna5nUcyswBmZhxx39baQ_.align = NIM_ALIGNOF(tyObject_Env_importerdotnim_transformImportAs___AMAna5nUcyswBmZhxx39baQ);
NTIobject__AMAna5nUcyswBmZhxx39baQ_.kind = 17;
NTIobject__AMAna5nUcyswBmZhxx39baQ_.base = (&NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_);
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_3_4[0] = &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[1];
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[1].kind = 1;
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[1].offset = offsetof(tyObject_Env_importerdotnim_transformImportAs___AMAna5nUcyswBmZhxx39baQ, colonstate_);
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[1].typ = (&NTIint__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[1].name = ":state";
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_3_4[1] = &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[2];
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[2].kind = 1;
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[2].offset = offsetof(tyObject_Env_importerdotnim_transformImportAs___AMAna5nUcyswBmZhxx39baQ, c1);
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[2].typ = (&NTIpcontext__C5LQliQ3Detta8PpLynVjQ_);
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[2].name = "c1";
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_3_4[2] = &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[3];
NTItupleLnode58pnode_importhidden58boolT__hv7XYxzNv29cYlH39cwb529ag_.size = sizeof(tyTuple__hv7XYxzNv29cYlH39cwb529ag);
NTItupleLnode58pnode_importhidden58boolT__hv7XYxzNv29cYlH39cwb529ag_.align = NIM_ALIGNOF(tyTuple__hv7XYxzNv29cYlH39cwb529ag);
NTItupleLnode58pnode_importhidden58boolT__hv7XYxzNv29cYlH39cwb529ag_.kind = 18;
NTItupleLnode58pnode_importhidden58boolT__hv7XYxzNv29cYlH39cwb529ag_.base = 0;
NTItupleLnode58pnode_importhidden58boolT__hv7XYxzNv29cYlH39cwb529ag_.flags = 2;
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_4_2[0] = &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[5];
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[5].kind = 1;
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[5].offset = offsetof(tyTuple__hv7XYxzNv29cYlH39cwb529ag, Field0);
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[5].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[5].name = "Field0";
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_4_2[1] = &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[6];
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[6].kind = 1;
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[6].offset = offsetof(tyTuple__hv7XYxzNv29cYlH39cwb529ag, Field1);
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[6].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[6].name = "Field1";
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[4].len = 2; TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[4].kind = 2; TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[4].sons = &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_4_2[0];
NTItupleLnode58pnode_importhidden58boolT__hv7XYxzNv29cYlH39cwb529ag_.node = &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[4];
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[3].kind = 1;
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[3].offset = offsetof(tyObject_Env_importerdotnim_transformImportAs___AMAna5nUcyswBmZhxx39baQ, ret2);
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[3].typ = (&NTItupleLnode58pnode_importhidden58boolT__hv7XYxzNv29cYlH39cwb529ag_);
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[3].name = "ret2";
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_3_4[3] = &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[7];
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[7].kind = 1;
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[7].offset = offsetof(tyObject_Env_importerdotnim_transformImportAs___AMAna5nUcyswBmZhxx39baQ, n3);
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[7].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[7].name = "n3";
TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[0].len = 4; TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[0].kind = 2; TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[0].sons = &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_3_4[0];
NTIobject__AMAna5nUcyswBmZhxx39baQ_.node = &TM__Sy4IFJJ0rwIQ9cBSYtIiY2w_0[0];
NTIrefobject__mzsJbF13j9a1gF8FsVcBslA_.size = sizeof(tyObject_Env_importerdotnim_transformImportAs___AMAna5nUcyswBmZhxx39baQ*);
NTIrefobject__mzsJbF13j9a1gF8FsVcBslA_.align = NIM_ALIGNOF(tyObject_Env_importerdotnim_transformImportAs___AMAna5nUcyswBmZhxx39baQ*);
NTIrefobject__mzsJbF13j9a1gF8FsVcBslA_.kind = 22;
NTIrefobject__mzsJbF13j9a1gF8FsVcBslA_.base = (&NTIobject__AMAna5nUcyswBmZhxx39baQ_);
NTIrefobject__mzsJbF13j9a1gF8FsVcBslA_.marker = Marker_tyRef__mzsJbF13j9a1gF8FsVcBslA;
NTIseqLtspecialwordT__s6XOb8vGaBHi7Py1r5uplQ_.size = sizeof(tySequence__s6XOb8vGaBHi7Py1r5uplQ*);
NTIseqLtspecialwordT__s6XOb8vGaBHi7Py1r5uplQ_.align = NIM_ALIGNOF(tySequence__s6XOb8vGaBHi7Py1r5uplQ*);
NTIseqLtspecialwordT__s6XOb8vGaBHi7Py1r5uplQ_.kind = 24;
NTIseqLtspecialwordT__s6XOb8vGaBHi7Py1r5uplQ_.base = (&NTItspecialword__N2XsqTpO5IzOf2KmXwk4Dw_);
NTIseqLtspecialwordT__s6XOb8vGaBHi7Py1r5uplQ_.flags = 2;
NTIseqLtspecialwordT__s6XOb8vGaBHi7Py1r5uplQ_.marker = Marker_tySequence__s6XOb8vGaBHi7Py1r5uplQ;
}

